@@ -5,10 +5,12 @@ private import PackageDescription
 private let swiftSettings = [
 	SwiftSetting
 	.enableUpcomingFeature("ExistentialAny"), // swiftformat:disable:this indent
+	.enableUpcomingFeature("ImmutableWeakCaptures"),
 	.enableUpcomingFeature("InferIsolatedConformances"),
 	.enableUpcomingFeature("InternalImportsByDefault"),
 	.enableUpcomingFeature("MemberImportVisibility"),
 	.enableUpcomingFeature("NonisolatedNonsendingByDefault"),
+	.unsafeFlags(["-warnings-as-errors"]),
 ]
 
 _ = Package(
@@ -16,7 +18,7 @@ _ = Package(
 	platforms: [.macOS(.v10_15)],
 	products: [.executable(name: "mas", targets: ["mas"])],
 	dependencies: [
-		.package(url: "https://github.com/apple/swift-argument-parser.git", from: "1.6.2"),
+		.package(url: "https://github.com/apple/swift-argument-parser.git", from: "1.7.0"),
 		.package(url: "https://github.com/apple/swift-atomics.git", from: "1.3.0"),
 		.package(url: "https://github.com/apple/swift-collections.git", from: "1.3.0"),
 		.package(url: "https://github.com/mxcl/Version.git", from: "2.2.0"),
