@@ -5,6 +5,7 @@
 // Copyright © 2025 mas-cli. All rights reserved.
 //
 
+private import ArgumentParser
 internal import Foundation
 private import StoreFoundation
 
@@ -17,9 +18,9 @@ typealias AppleAccount = (
 var appleAccount: AppleAccount {
 	get async throws {
 		if #available(macOS 12, *) {
-			// Account information is no longer available on macOS 12+
+			// Account information is no longer available starting with macOS 12 (Monterey)
 			// https://github.com/mas-cli/mas/issues/417
-			throw MASError.notSupported
+			throw MASError.unsupportedCommand(MAS.Account._commandName)
 		}
 		return await withCheckedContinuation { continuation in
 			ISServiceProxy.genericShared().accountService.primaryAccount { account in
