@@ -38,6 +38,10 @@ struct MAS: AsyncParsableCommand, Sendable {
 
 	static let printer = Printer()
 
+	static var _errorPrefix: String { // swiftlint:disable:this identifier_name
+		"\(mas.format(prefix: "\(errorPrefix)", format: errorFormat, for: FileHandle.standardError)) "
+	}
+
 	private static func main() async { // swiftlint:disable:this unused_declaration
 		await main(nil)
 	}
@@ -81,8 +85,8 @@ extension MAS {
 			try ProcessInfo.processInfo.runAsSudoEffectiveUserAndSudoEffectiveGroupIfRootEffectiveUser {
 				try body(command)
 			}
-		} catch let error as MASError {
-			printer.error(error: error)
+		} catch {
+			printer.error(error: try error.failure)
 		}
 	}
 
@@ -94,8 +98,20 @@ extension MAS {
 			try await ProcessInfo.processInfo.runAsSudoEffectiveUserAndSudoEffectiveGroupIfRootEffectiveUser {
 				try await body(command)
 			}
-		} catch let error as MASError {
-			printer.error(error: error)
+		} catch {
+			printer.error(error: try error.failure)
+		}
+	}
+}
+
+private extension Error {
+	var failure: Self {
+		get throws {
+			guard !MAS.exitCode(for: self).isSuccess else {
+				throw self
+			}
+
+			return self
 		}
 	}
 }
