@@ -24,12 +24,8 @@ extension MAS {
 		@OptionGroup
 		private var searchTermOptionGroup: SearchTermOptionGroup
 
-		func run() async {
-			do {
-				try await run(appCatalog: ITunesSearchAppCatalog())
-			} catch {
-				printer.error(error: error)
-			}
+		func run() async throws {
+			try await run(appCatalog: ITunesSearchAppCatalog())
 		}
 
 		private func run(appCatalog: some AppCatalog) async throws {
@@ -52,7 +48,7 @@ extension MAS {
 						catalogApp.adamID,
 						catalogApp.name.padding(toLength: maxNameLength, withPad: " ", startingAt: 0),
 						catalogApp.version,
-						catalogApp.formattedPrice
+						catalogApp.displayPrice
 					)
 				}
 				.joined(separator: "\n")
