@@ -8,19 +8,14 @@
 internal import ArgumentParser
 
 extension MAS {
-	/// Outputs the version of the mas tool.
+	/// Outputs the version of mas.
 	struct Version: ParsableCommand {
 		static let configuration = CommandConfiguration(
 			abstract: "Output version number"
 		)
 
-		/// Runs the command.
-		func run() throws {
-			try mas.run { run(printer: $0) }
-		}
-
-		func run(printer: Printer) {
-			printer.info(Package.version)
+		func run() {
+			printer.info(MAS.version)
 		}
 	}
 }
