@@ -6,7 +6,7 @@
 //
 
 /// Protocol for searching for, and for looking up, apps from the MAS catalog.
-protocol AppCatalog {
+protocol AppCatalog: Sendable {
 	/// Looks up app details.
 	///
 	/// - Parameters:
@@ -37,7 +37,7 @@ extension AppCatalog {
 	/// - Throws: A `MASError.unknownAppID(appID)` if `appID` is invalid.
 	///   Some other `Error` if any other problem occurs.
 	func lookup(appID: AppID) async throws -> CatalogApp {
-		try await lookup(appID: appID, inRegion: region)
+		try await lookup(appID: appID, inRegion: appStoreRegion)
 	}
 
 	/// Searches for apps.
@@ -46,6 +46,6 @@ extension AppCatalog {
 	/// - Returns: A `[CatalogApp]` matching `searchTerm`.
 	/// - Throws: An `Error` if any problem occurs.
 	func search(for searchTerm: String) async throws -> [CatalogApp] {
-		try await search(for: searchTerm, inRegion: region)
+		try await search(for: searchTerm, inRegion: appStoreRegion)
 	}
 }
